@@ -164,11 +164,14 @@ get_unweighted <- function(table, disenio, var, domains) {
 #-----------------------------------------------------------------------
 
 get_log_cv <- function(data) {
-
-  data <- data %>%
-    dplyr::mutate(log_cv = dplyr::case_when(.data$stat<0.5 ~ .data$cv/(-log(.data$stat)),
-                                            .data$stat>=0.5 ~ .data$cv/-log(1-.data$stat))
-    )
+  if(sum(data$stat>1)>0){
+    warning('Oops! We detected a ratio estimation over 1. The log_cv cannot be calculated.')
+  }else{
+    data <- data %>%
+      dplyr::mutate(log_cv = dplyr::case_when(.data$stat<0.5 ~ .data$cv/(-log(.data$stat)),
+                                              .data$stat>=0.5 ~ .data$cv/-log(1-.data$stat))
+                    )
+    }
 
   return(data)
 }
@@ -939,6 +942,7 @@ get_ess <- function(ess, env = parent.frame() ) {
 #' @param deff \code{boolean} Design effect
 #' @param ess \code{boolean} Effective sample size
 #' @param rel_error \code{boolean} Relative error
+#' @param log_cv \code{boolean} indicating if the log cv must be returned. Used for ratios between 0 and 1.
 #' @param rm.na \code{boolean} indicating if NA values must be removed
 #' @param unweighted \code{boolean} Add non weighted count if it is required
 #' @importFrom rlang :=
@@ -948,7 +952,7 @@ get_ess <- function(ess, env = parent.frame() ) {
 #'
 
 create_ratio_internal <- function(var,denominator, domains = NULL, subpop = NULL, disenio, ci = FALSE, deff = FALSE, ess = FALSE,
-                                  ajuste_ene = FALSE, unweighted = FALSE, rel_error = FALSE, rm.na = FALSE) {
+                                  ajuste_ene = FALSE, unweighted = FALSE, rel_error = FALSE, log_cv = FALSE, rm.na = FALSE) {
 
   # get design variables
   design_vars <- get_design_vars(disenio )
@@ -1035,6 +1039,11 @@ create_ratio_internal <- function(var,denominator, domains = NULL, subpop = NULL
       dplyr::mutate(relative_error = stats::qt(c(.975), df = .data$df) * cv)
   }
 
+  # Add log cv, if the user uses this parameter
+  if (log_cv) {
+    final <- get_log_cv(final)
+  }
+
   # add the ess if the user uses this parameter
   final <- get_ess(ess)
 
